@@ -4,4 +4,4 @@ import click
 @click.command("run")
 def cli():
     """no-op command used for testing only..."""
-    click.secho('completed', fg='green')
+    click.secho("completed", fg="green")
